part of trober_sdk.api;

class DefaultApi {
  final DefaultApiDelegate apiDelegate;
  DefaultApi(ApiClient apiClient)
      : assert(apiClient != null),
        apiDelegate = DefaultApiDelegate(apiClient);

  /// Get supported App info
  ///
  /// Get supported App info
  Future<AppInfo> appinfoGet({Options options}) async {
    final response = await apiDelegate.appinfoGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.appinfoGet_decode(response);
    }
  }

  /// Get supported App info
  ///
  /// Get supported App info
  /// List all Carriers
  ///
  /// List all Carriers
  Future<List<Carrier>> carriersGet(
      {Options options,
      String tenantId,
      String name,
      int page,
      CarrierType type}) async {
    final response = await apiDelegate.carriersGet(
        options: options,
        tenantId: tenantId,
        name: name,
        page: page,
        type: type);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersGet_decode(response);
    }
  }

  /// List all Carriers
  ///
  /// List all Carriers
  /// Get carrier details
  ///
  /// Get carrier details
  Future<Carrier> carriersIdGet(String id,
      {Options options, String tenantId}) async {
    final response = await apiDelegate.carriersIdGet(id,
        options: options, tenantId: tenantId);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersIdGet_decode(response);
    }
  }

  /// Get carrier details
  ///
  /// Get carrier details
  /// Update an existing carrier
  ///
  /// Update an existing carrier
  Future<Carrier> carriersIdPut(String id,
      {Options options, Carrier carrier}) async {
    final response =
        await apiDelegate.carriersIdPut(id, options: options, carrier: carrier);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersIdPut_decode(response);
    }
  }

  /// Update an existing carrier
  ///
  /// Update an existing carrier
  /// Create a new Carrier
  ///
  /// Create a new Carrier
  Future<Carrier> carriersPost({Options options, Carrier carrier}) async {
    final response =
        await apiDelegate.carriersPost(options: options, carrier: carrier);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersPost_decode(response);
    }
  }

  /// Create a new Carrier
  ///
  /// Create a new Carrier
  /// List all Customers
  ///
  /// List all Customers
  Future<List<Customer>> customersGet(
      {Options options, String tenantId, String name, int page}) async {
    final response = await apiDelegate.customersGet(
        options: options, tenantId: tenantId, name: name, page: page);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersGet_decode(response);
    }
  }

  /// List all Customers
  ///
  /// List all Customers
  /// Get customer details
  ///
  /// Get customer details
  Future<Customer> customersIdGet(String id,
      {Options options, String tenantId}) async {
    final response = await apiDelegate.customersIdGet(id,
        options: options, tenantId: tenantId);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersIdGet_decode(response);
    }
  }

  /// Get customer details
  ///
  /// Get customer details
  /// Update an existing customer
  ///
  /// Update an existing customer
  Future<Customer> customersIdPut(String id,
      {Options options, Customer customer}) async {
    final response = await apiDelegate.customersIdPut(id,
        options: options, customer: customer);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersIdPut_decode(response);
    }
  }

  /// Update an existing customer
  ///
  /// Update an existing customer
  /// Create a new Customer
  ///
  /// Create a new Customer
  Future<Customer> customersPost({Options options, Customer customer}) async {
    final response =
        await apiDelegate.customersPost(options: options, customer: customer);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersPost_decode(response);
    }
  }

  /// Create a new Customer
  ///
  /// Create a new Customer
  /// Get server health
  ///
  /// Get server health status
  Future healthGet({Options options}) async {
    final response = await apiDelegate.healthGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.healthGet_decode(response);
    }
  }

  /// Get server health
  ///
  /// Get server health status
  /// List all Orders
  ///
  /// List all Orders
  Future<List<Order>> ordersGet(
      {Options options,
      String tenantId,
      int page,
      String customerId,
      String serialNumber,
      OrderStatus status}) async {
    final response = await apiDelegate.ordersGet(
        options: options,
        tenantId: tenantId,
        page: page,
        customerId: customerId,
        serialNumber: serialNumber,
        status: status);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersGet_decode(response);
    }
  }

  /// List all Orders
  ///
  /// List all Orders
  /// Get order details
  ///
  /// Get order details
  Future<Order> ordersIdGet(String id,
      {Options options, String tenantId}) async {
    final response =
        await apiDelegate.ordersIdGet(id, options: options, tenantId: tenantId);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersIdGet_decode(response);
    }
  }

  /// Get order details
  ///
  /// Get order details
  /// Update an existing order
  ///
  /// Update an existing order
  Future<Order> ordersIdPut(String id, {Options options, Order order}) async {
    final response =
        await apiDelegate.ordersIdPut(id, options: options, order: order);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersIdPut_decode(response);
    }
  }

  /// Update an existing order
  ///
  /// Update an existing order
  /// Create a new Order
  ///
  /// Create a new Order
  Future<Order> ordersPost({Options options, Order order}) async {
    final response =
        await apiDelegate.ordersPost(options: options, order: order);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersPost_decode(response);
    }
  }

  /// Create a new Order
  ///
  /// Create a new Order
  /// Register the device for the user
  ///
  /// Register the device for the user
  Future selfDeviceRegisterPost(
      {Options options, InlineObject1 inlineObject1}) async {
    final response = await apiDelegate.selfDeviceRegisterPost(
        options: options, inlineObject1: inlineObject1);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.selfDeviceRegisterPost_decode(response);
    }
  }

  /// Register the device for the user
  ///
  /// Register the device for the user
  /// Remove the device for the user
  ///
  /// Remove the device for the user
  Future selfDeviceRemoveDelete(
      {Options options, InlineObject2 inlineObject2}) async {
    final response = await apiDelegate.selfDeviceRemoveDelete(
        options: options, inlineObject2: inlineObject2);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.selfDeviceRemoveDelete_decode(response);
    }
  }

  /// Remove the device for the user
  ///
  /// Remove the device for the user
  /// Get details of the logged in user
  ///
  /// Get details of the logged in user
  Future<User> selfGet({Options options}) async {
    final response = await apiDelegate.selfGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.selfGet_decode(response);
    }
  }

  /// Get details of the logged in user
  ///
  /// Get details of the logged in user
  /// Get tenant details of the logged in user
  ///
  /// Get tenant details of the logged in user
  Future<Tenant> selfTenantGet({Options options}) async {
    final response = await apiDelegate.selfTenantGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.selfTenantGet_decode(response);
    }
  }

  /// Get tenant details of the logged in user
  ///
  /// Get tenant details of the logged in user
  /// List all Shipments
  ///
  /// List all Shipments
  Future<List<Shipment>> shipmentsGet(
      {Options options,
      String tenantId,
      String orderId,
      String carrierId,
      int page,
      String driverId,
      String serialNumber,
      ShipmentType type,
      ShipmentStatus status,
      ShipmentSize size}) async {
    final response = await apiDelegate.shipmentsGet(
        options: options,
        tenantId: tenantId,
        orderId: orderId,
        carrierId: carrierId,
        page: page,
        driverId: driverId,
        serialNumber: serialNumber,
        type: type,
        status: status,
        size: size);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.shipmentsGet_decode(response);
    }
  }

  /// List all Shipments
  ///
  /// List all Shipments
  /// Get shipment details
  ///
  /// Get shipment details
  Future<Shipment> shipmentsIdGet(String id,
      {Options options, String tenantId}) async {
    final response = await apiDelegate.shipmentsIdGet(id,
        options: options, tenantId: tenantId);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.shipmentsIdGet_decode(response);
    }
  }

  /// Get shipment details
  ///
  /// Get shipment details
  /// Update an existing shipment
  ///
  /// Update an existing shipment
  Future<Shipment> shipmentsIdPut(String id,
      {Options options, Shipment shipment}) async {
    final response = await apiDelegate.shipmentsIdPut(id,
        options: options, shipment: shipment);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.shipmentsIdPut_decode(response);
    }
  }

  /// Update an existing shipment
  ///
  /// Update an existing shipment
  /// Update the status of an existing shipment
  ///
  /// Update the status of an existing shipment
  Future<Shipment> shipmentsIdUpdateStatusStatusPatch(String id, String status,
      {Options options, InlineObject inlineObject}) async {
    final response = await apiDelegate.shipmentsIdUpdateStatusStatusPatch(
        id, status,
        options: options, inlineObject: inlineObject);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate
          .shipmentsIdUpdateStatusStatusPatch_decode(response);
    }
  }

  /// Update the status of an existing shipment
  ///
  /// Update the status of an existing shipment
  /// Create a new Shipment
  ///
  /// Create a new Shipment
  Future<Shipment> shipmentsPost({Options options, Shipment shipment}) async {
    final response =
        await apiDelegate.shipmentsPost(options: options, shipment: shipment);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.shipmentsPost_decode(response);
    }
  }

  /// Create a new Shipment
  ///
  /// Create a new Shipment
  /// List all tenants
  ///
  /// List all tenants
  Future<List<Tenant>> tenantsGet(
      {Options options, String name, int page, TenantType type}) async {
    final response = await apiDelegate.tenantsGet(
        options: options, name: name, page: page, type: type);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsGet_decode(response);
    }
  }

  /// List all tenants
  ///
  /// List all tenants
  /// Get tenant details
  ///
  /// Get tenant details
  Future<Tenant> tenantsIdGet(String id, {Options options}) async {
    final response = await apiDelegate.tenantsIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsIdGet_decode(response);
    }
  }

  /// Get tenant details
  ///
  /// Get tenant details
  /// Update an existing tenant
  ///
  /// Update an existing tenant
  Future<Tenant> tenantsIdPut(String id,
      {Options options, Tenant tenant}) async {
    final response =
        await apiDelegate.tenantsIdPut(id, options: options, tenant: tenant);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsIdPut_decode(response);
    }
  }

  /// Update an existing tenant
  ///
  /// Update an existing tenant
  /// Create a new tenant
  ///
  /// Create a new tenant
  Future<Tenant> tenantsPost({Options options, Tenant tenant}) async {
    final response =
        await apiDelegate.tenantsPost(options: options, tenant: tenant);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsPost_decode(response);
    }
  }

  /// Create a new tenant
  ///
  /// Create a new tenant
  /// List all Terminals
  ///
  /// List all Terminals
  Future<List<Terminal>> terminalsGet(
      {Options options,
      String tenantId,
      int page,
      String name,
      TerminalType type}) async {
    final response = await apiDelegate.terminalsGet(
        options: options,
        tenantId: tenantId,
        page: page,
        name: name,
        type: type);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsGet_decode(response);
    }
  }

  /// List all Terminals
  ///
  /// List all Terminals
  /// Get terminal details
  ///
  /// Get terminal details
  Future<Terminal> terminalsIdGet(String id,
      {Options options, String tenantId}) async {
    final response = await apiDelegate.terminalsIdGet(id,
        options: options, tenantId: tenantId);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsIdGet_decode(response);
    }
  }

  /// Get terminal details
  ///
  /// Get terminal details
  /// Update an existing terminal
  ///
  /// Update an existing terminal
  Future<Terminal> terminalsIdPut(String id,
      {Options options, Terminal terminal}) async {
    final response = await apiDelegate.terminalsIdPut(id,
        options: options, terminal: terminal);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsIdPut_decode(response);
    }
  }

  /// Update an existing terminal
  ///
  /// Update an existing terminal
  /// Create a new Terminal
  ///
  /// Create a new Terminal
  Future<Terminal> terminalsPost({Options options, Terminal terminal}) async {
    final response =
        await apiDelegate.terminalsPost(options: options, terminal: terminal);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsPost_decode(response);
    }
  }

  /// Create a new Terminal
  ///
  /// Create a new Terminal
  /// List all users
  ///
  /// List all users
  Future<List<User>> usersGet(
      {Options options,
      String tenantId,
      int page,
      String name,
      UserRole role}) async {
    final response = await apiDelegate.usersGet(
        options: options,
        tenantId: tenantId,
        page: page,
        name: name,
        role: role);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersGet_decode(response);
    }
  }

  /// List all users
  ///
  /// List all users
  /// Delete the user
  ///
  /// Delete the user
  Future usersIdDelete(String id, {Options options}) async {
    final response = await apiDelegate.usersIdDelete(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersIdDelete_decode(response);
    }
  }

  /// Delete the user
  ///
  /// Delete the user
  /// Get user details
  ///
  /// Get user details
  Future<User> usersIdGet(String id, {Options options, String tenantId}) async {
    final response =
        await apiDelegate.usersIdGet(id, options: options, tenantId: tenantId);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersIdGet_decode(response);
    }
  }

  /// Get user details
  ///
  /// Get user details
  /// Update an existing user
  ///
  /// Update an existing user
  Future<User> usersIdPut(String id, {Options options, User user}) async {
    final response =
        await apiDelegate.usersIdPut(id, options: options, user: user);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersIdPut_decode(response);
    }
  }

  /// Update an existing user
  ///
  /// Update an existing user
  /// Create a new user
  ///
  /// Create a new user
  Future<User> usersPost({Options options, User user}) async {
    final response = await apiDelegate.usersPost(options: options, user: user);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersPost_decode(response);
    }
  }

  /// Create a new user
  ///
  /// Create a new user
}

class DefaultApiDelegate {
  final ApiClient apiClient;

  DefaultApiDelegate(this.apiClient) : assert(apiClient != null);

  Future<ApiResponse> appinfoGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/appinfo';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<AppInfo> appinfoGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'AppInfo') as AppInfo;
    }

    return null;
  }

  Future<ApiResponse> carriersGet(
      {Options options,
      String tenantId,
      String name,
      int page,
      CarrierType type}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/carriers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Carrier>> carriersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Carrier>') as List)
          .map((item) => item as Carrier)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> carriersIdGet(String id,
      {Options options, String tenantId}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/carriers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Carrier') as Carrier;
    }

    return null;
  }

  Future<ApiResponse> carriersIdPut(String id,
      {Options options, Carrier carrier}) async {
    Object postBody = carrier;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/carriers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Carrier') as Carrier;
    }

    return null;
  }

  Future<ApiResponse> carriersPost({Options options, Carrier carrier}) async {
    Object postBody = carrier;

    // verify required params are set

    // create path and map variables
    final __path = '/carriers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Carrier') as Carrier;
    }

    return null;
  }

  Future<ApiResponse> customersGet(
      {Options options, String tenantId, String name, int page}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/customers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Customer>> customersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Customer>') as List)
          .map((item) => item as Customer)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> customersIdGet(String id,
      {Options options, String tenantId}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/customers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Customer') as Customer;
    }

    return null;
  }

  Future<ApiResponse> customersIdPut(String id,
      {Options options, Customer customer}) async {
    Object postBody = customer;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/customers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Customer') as Customer;
    }

    return null;
  }

  Future<ApiResponse> customersPost(
      {Options options, Customer customer}) async {
    Object postBody = customer;

    // verify required params are set

    // create path and map variables
    final __path = '/customers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Customer') as Customer;
    }

    return null;
  }

  Future<ApiResponse> healthGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/health';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>[];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future healthGet_decode(ApiResponse response) async {
    if (response.body != null) {}

    return;
  }

  Future<ApiResponse> ordersGet(
      {Options options,
      String tenantId,
      int page,
      String customerId,
      String serialNumber,
      OrderStatus status}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/orders';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (customerId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'customer_id', customerId));
    }
    if (serialNumber != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'serial_number', serialNumber));
    }
    if (status != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'status', status));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Order>> ordersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Order>') as List)
          .map((item) => item as Order)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> ordersIdGet(String id,
      {Options options, String tenantId}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/orders/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Order') as Order;
    }

    return null;
  }

  Future<ApiResponse> ordersIdPut(String id,
      {Options options, Order order}) async {
    Object postBody = order;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/orders/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Order') as Order;
    }

    return null;
  }

  Future<ApiResponse> ordersPost({Options options, Order order}) async {
    Object postBody = order;

    // verify required params are set

    // create path and map variables
    final __path = '/orders';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Order') as Order;
    }

    return null;
  }

  Future<ApiResponse> selfDeviceRegisterPost(
      {Options options, InlineObject1 inlineObject1}) async {
    Object postBody = inlineObject1;

    // verify required params are set

    // create path and map variables
    final __path = '/self/device-register';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future selfDeviceRegisterPost_decode(ApiResponse response) async {
    if (response.body != null) {}

    return;
  }

  Future<ApiResponse> selfDeviceRemoveDelete(
      {Options options, InlineObject2 inlineObject2}) async {
    Object postBody = inlineObject2;

    // verify required params are set

    // create path and map variables
    final __path = '/self/device-remove';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'DELETE';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future selfDeviceRemoveDelete_decode(ApiResponse response) async {
    if (response.body != null) {}

    return;
  }

  Future<ApiResponse> selfGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/self';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> selfGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }

  Future<ApiResponse> selfTenantGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/self/tenant';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> selfTenantGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> shipmentsGet(
      {Options options,
      String tenantId,
      String orderId,
      String carrierId,
      int page,
      String driverId,
      String serialNumber,
      ShipmentType type,
      ShipmentStatus status,
      ShipmentSize size}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/shipments';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (orderId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'order_id', orderId));
    }
    if (carrierId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'carrier_id', carrierId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (driverId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'driver_id', driverId));
    }
    if (serialNumber != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'serial_number', serialNumber));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }
    if (status != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'status', status));
    }
    if (size != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'size', size));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Shipment>> shipmentsGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Shipment>') as List)
          .map((item) => item as Shipment)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> shipmentsIdGet(String id,
      {Options options, String tenantId}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/shipments/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Shipment> shipmentsIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Shipment') as Shipment;
    }

    return null;
  }

  Future<ApiResponse> shipmentsIdPut(String id,
      {Options options, Shipment shipment}) async {
    Object postBody = shipment;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/shipments/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Shipment> shipmentsIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Shipment') as Shipment;
    }

    return null;
  }

  Future<ApiResponse> shipmentsIdUpdateStatusStatusPatch(
      String id, String status,
      {Options options, InlineObject inlineObject}) async {
    Object postBody = inlineObject;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }
    if (status == null) {
      throw ApiException(400, 'Missing required param: status');
    }

    // create path and map variables
    final __path = '/shipments/{id}/updateStatus/{status}'
        .replaceAll('{' + 'id' + '}', id.toString())
        .replaceAll('{' + 'status' + '}', status.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Shipment> shipmentsIdUpdateStatusStatusPatch_decode(
      ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Shipment') as Shipment;
    }

    return null;
  }

  Future<ApiResponse> shipmentsPost(
      {Options options, Shipment shipment}) async {
    Object postBody = shipment;

    // verify required params are set

    // create path and map variables
    final __path = '/shipments';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Shipment> shipmentsPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Shipment') as Shipment;
    }

    return null;
  }

  Future<ApiResponse> tenantsGet(
      {Options options, String name, int page, TenantType type}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/tenants';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Tenant>> tenantsGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Tenant>') as List)
          .map((item) => item as Tenant)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> tenantsIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/tenants/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> tenantsIdPut(String id,
      {Options options, Tenant tenant}) async {
    Object postBody = tenant;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/tenants/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> tenantsPost({Options options, Tenant tenant}) async {
    Object postBody = tenant;

    // verify required params are set

    // create path and map variables
    final __path = '/tenants';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> terminalsGet(
      {Options options,
      String tenantId,
      int page,
      String name,
      TerminalType type}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/terminals';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Terminal>> terminalsGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Terminal>') as List)
          .map((item) => item as Terminal)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> terminalsIdGet(String id,
      {Options options, String tenantId}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/terminals/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Terminal') as Terminal;
    }

    return null;
  }

  Future<ApiResponse> terminalsIdPut(String id,
      {Options options, Terminal terminal}) async {
    Object postBody = terminal;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/terminals/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Terminal') as Terminal;
    }

    return null;
  }

  Future<ApiResponse> terminalsPost(
      {Options options, Terminal terminal}) async {
    Object postBody = terminal;

    // verify required params are set

    // create path and map variables
    final __path = '/terminals';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Terminal') as Terminal;
    }

    return null;
  }

  Future<ApiResponse> usersGet(
      {Options options,
      String tenantId,
      int page,
      String name,
      UserRole role}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/users';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (role != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'role', role));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<User>> usersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<User>') as List)
          .map((item) => item as User)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> usersIdDelete(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'DELETE';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future usersIdDelete_decode(ApiResponse response) async {
    if (response.body != null) {}

    return;
  }

  Future<ApiResponse> usersIdGet(String id,
      {Options options, String tenantId}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }

  Future<ApiResponse> usersIdPut(String id,
      {Options options, User user}) async {
    Object postBody = user;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersIdPut_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }

  Future<ApiResponse> usersPost({Options options, User user}) async {
    Object postBody = user;

    // verify required params are set

    // create path and map variables
    final __path = '/users';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }
}
